==> bsl-language-server-0.20.0-ra.2.jar: com/github/_1c_syntax/bsl/languageserver/diagnostics/ru/WrongUseFunctionProceedWithCall.md <==
# Некорректное использование функции ПродолжитьВызов() (WrongUseFunctionProceedWithCall)

|   Тип    |    Поддерживаются<br>языки    |   Важность    |    Включена<br>по умолчанию    |    Время на<br>исправление (мин)    |             Теги              |
|:--------:|:-----------------------------:|:-------------:|:------------------------------:|:-----------------------------------:|:-----------------------------:|
| `Ошибка` |             `BSL`             | `Блокирующий` |              `Да`              |                 `1`                 |    `error`<br>`suspicious`    |

<!-- Блоки выше заполняются автоматически, не трогать -->
## Описание диагностики
<!-- Описание диагностики заполняется вручную. Необходимо понятным языком описать смысл и схему работу -->
Вызов функции ПродолжитьВызов можно использовать только в расширениях и только в методах с аннотацией &Вместо.

## Примеры
<!-- В данном разделе приводятся примеры, на которые диагностика срабатывает, а также можно привести пример, как можно исправить ситуацию -->
```bsl
&НаКлиенте
Процедура Тест()
    
    // этот код возможно был внесен копипастой, при переносе из расширения
    ПродолжитьВызов(); // Срабатывание здесь
    
КонецПроцедуры
```

## Источники
<!-- Необходимо указывать ссылки на все источники, из которых почерпнута информация для создания диагностики -->

Источник: [Расширения конфигураций. Функциональность -> Модули](https://its.1c.ru/db/pubextensions#content:54:1)

## Сниппеты

<!-- Блоки ниже заполняются автоматически, не трогать -->
### Экранирование кода

```bsl
// BSLLS:WrongUseFunctionProceedWithCall-off
// BSLLS:WrongUseFunctionProceedWithCall-on
```

### Параметр конфигурационного файла

```json
"WrongUseFunctionProceedWithCall": false
```

==> bsl-language-server-0.24.1.jar: com/github/_1c_syntax/bsl/languageserver/diagnostics/ru/WrongUseFunctionProceedWithCall.md <==
# Некорректное использование функции ПродолжитьВызов() (WrongUseFunctionProceedWithCall)

|   Тип    |    Поддерживаются<br>языки    |   Важность    |    Включена<br>по умолчанию    |    Время на<br>исправление (мин)    |             Теги              |
|:--------:|:-----------------------------:|:-------------:|:------------------------------:|:-----------------------------------:|:-----------------------------:|
| `Ошибка` |             `BSL`             | `Блокирующий` |              `Да`              |                 `1`                 |    `error`<br>`suspicious`    |

<!-- Блоки выше заполняются автоматически, не трогать -->
## Описание диагностики
<!-- Описание диагностики заполняется вручную. Необходимо понятным языком описать смысл и схему работу -->

Использование функции `ПродолжитьВызов` не в методах расширения с аннотацией `&Вместо` приведет к ошибке времени выполнения.

## Примеры
<!-- В данном разделе приводятся примеры, на которые диагностика срабатывает, а также можно привести пример, как можно исправить ситуацию -->

```bsl
&НаКлиенте
Процедура Тест()
    
    // этот код возможно был внесен копипастой, при переносе из расширения
    ПродолжитьВызов(); // Срабатывание здесь
    
КонецПроцедуры
```

## Источники
<!-- Необходимо указывать ссылки на все источники, из которых почерпнута информация для создания диагностики -->

Источник: [Расширения конфигураций. Функциональность -> Модули](https://its.1c.ru/db/pubextensions#content:54:1)

## Сниппеты

<!-- Блоки ниже заполняются автоматически, не трогать -->
### Экранирование кода

```bsl
// BSLLS:WrongUseFunctionProceedWithCall-off
// BSLLS:WrongUseFunctionProceedWithCall-on
```

### Параметр конфигурационного файла

```json
"WrongUseFunctionProceedWithCall": false
```
